@@ -5,7 +5,9 @@ from ._frequency_cfd import (fitz_r,
                              m_and_m,
                              fitz,
                              f_and_k,
-                             tretter_f)
+                             tretter_f,
+                             maxcorfreq,
+                             maxcorfreq_real)
 
 from ._frequency_fft import (ml_fft, 
                              barycenter_fft,
